@@ -54,6 +54,8 @@
 (declare-function treesit-fold-range-fish-function "treesit-fold.el")
 (declare-function treesit-fold-range-fish-if "treesit-fold.el")
 (declare-function treesit-fold-range-fish-case "treesit-fold.el")
+(declare-function treesit-fold-range-fsharp-module-defn "treesit-fold.el")
+(declare-function treesit-fold-range-fsharp-record-type-defn "treesit-fold.el")
 (declare-function treesit-fold-range-haskell-function "treesit-fold.el")
 (declare-function treesit-fold-range-html "treesit-fold.el")
 (declare-function treesit-fold-range-julia-function "treesit-fold.el")
@@ -93,6 +95,7 @@
 (declare-function treesit-fold-range-python-block "treesit-fold.el")
 (declare-function treesit-fold-range-python-def "treesit-fold.el")
 (declare-function treesit-fold-range-python-expression-statement "treesit-fold.el")
+(declare-function treesit-fold-range-ron-struct "treesit-fold.el")
 (declare-function treesit-fold-range-rst-body "treesit-fold.el")
 (declare-function treesit-fold-range-ruby-class-def "treesit-fold.el")
 (declare-function treesit-fold-range-ruby-if "treesit-fold.el")
@@ -103,6 +106,7 @@
 (declare-function treesit-fold-range-verilog-initial-construct "treesit-fold.el")
 (declare-function treesit-fold-range-verilog-module "treesit-fold.el")
 (declare-function treesit-fold-range-vhdl-package "treesit-fold.el")
+(declare-function treesit-fold-range-vim-for-loop "treesit-fold.el")
 (declare-function treesit-fold-range-vhdl-type "treesit-fold.el")
 
 ;;
@@ -274,6 +278,14 @@
      . (lambda (node offset)
          (treesit-fold-range-line-comment node offset "#")))))
 
+(defun treesit-fold-parsers-fsharp ()
+  "Rules set for F#."
+  '((module_defn      . treesit-fold-range-fsharp-module-defn)
+    (list_expression  . treesit-fold-range-seq)
+    (record_type_defn . treesit-fold-range-fsharp-record-type-defn)
+    (line_comment     . treesit-fold-range-c-like-comment)
+    (block_comment    . (treesit-fold-range-seq 1 -1))))
+
 (defun treesit-fold-parsers-gdscript ()
   "Rule set for GGScript."
   '((body . (treesit-fold-range-seq -1 1))
@@ -544,6 +556,14 @@
   '((body    . treesit-fold-range-seq)
     (comment . treesit-fold-range-c-like-comment)))
 
+(defun treesit-fold-parsers-nim ()
+  "Rule set for Nim."
+  '((array_construction . treesit-fold-range-seq)
+    (for                . treesit-fold-range-seq)
+    (comment
+     . (lambda (node offset)
+         (treesit-fold-range-line-comment node offset "#")))))
+
 (defun treesit-fold-parsers-nix ()
   "Rule set for Nix."
   '((attrset_expression . treesit-fold-range-seq)
@@ -630,7 +650,7 @@
   "Rule set for RON."
   '((array  . treesit-fold-range-seq)
     (map    . treesit-fold-range-seq)
-    (struct . treesit-fold-range-seq)
+    (struct . treesit-fold-range-ron-struct)
     (line_comment
      . (lambda (node offset)
          (treesit-fold-range-line-comment node
@@ -723,8 +743,9 @@
 
 (defun treesit-fold-parsers-toml ()
   "Rule set for TOML."
-  '((table . treesit-fold-range-toml-table)
-    (array . treesit-fold-range-seq)
+  '((table        . treesit-fold-range-toml-table)
+    (array        . treesit-fold-range-seq)
+    (inline_table . treesit-fold-range-seq)
     (comment
      . (lambda (node offset)
          (treesit-fold-range-line-comment node offset "#")))))
@@ -758,10 +779,18 @@
     (enumeration_type_definition . treesit-fold-range-seq)
     (comment                     . treesit-fold-range-lua-comment)))
 
-(defun treesit-fold-parsers-vimscript ()
-  "Rule set for Vimscript."
-  '((function_definition . treesit-fold-range-vimscript-function)
-    (if_statement        . (treesit-fold-range-seq 1 -4))))
+(defun treesit-fold-parsers-vim ()
+  "Rule set for Vim."
+  '((function_definition . treesit-fold-range-vim-for-loop)
+    (for_loop            . treesit-fold-range-vim-for-loop)
+    (while_loop          . treesit-fold-range-vim-for-loop)
+    (if_statement        . treesit-fold-range-vim-for-loop)
+    (elseif_statement    . treesit-fold-range-vim-for-loop)
+    (else_statement      . treesit-fold-range-vim-for-loop)
+    (list                . treesit-fold-range-seq)
+    (comment
+     . (lambda (node offset)
+         (treesit-fold-range-line-comment node offset "\"")))))
 
 (defun treesit-fold-parsers-xml ()
   "Rule set for XML."
