@@ -178,6 +178,10 @@ type of content by checking the word boundary's existence."
   "Extract summary from DOC-STR in Org block."
   (treesit-fold-summary--doc-extract doc-str '()))
 
+(defun treesit-fold-summary-vim (doc-str)
+  "Extract summary from DOC-STR in Vim."
+  (treesit-fold-summary--generic doc-str '("\"")))
+
 (defun treesit-fold-summary-xml (doc-str)
   "Extract summary from DOC-STR in XML."
   (treesit-fold-summary--generic doc-str "-"))
@@ -186,6 +190,10 @@ type of content by checking the word boundary's existence."
   "Extract summary from DOC-STR in Julia."
   (treesit-fold-summary--generic doc-str '("#" "\"\"\"")))
 
+(defun treesit-fold-summary-ocaml (doc-str)
+  "Extract summary from DOC-STR in OCaml."
+  (treesit-fold-summary--generic doc-str '("\"\"")))
+
 ;;
 ;; (@* "Core" )
 ;;
@@ -203,38 +211,55 @@ type of content by checking the word boundary's existence."
     (beancount-mode         . treesit-fold-summary-elisp)
     (c-mode                 . treesit-fold-summary-c)
     (c++-mode               . treesit-fold-summary-c)
+    (caml-mode              . treesit-fold-summary-ocaml)
     (cmake-mode             . treesit-fold-summary-ruby-doc)
     (clojure-mode           . treesit-fold-summary-elisp)
+    (clojure-ts-mode        . treesit-fold-summary-elisp)
     (csharp-mode            . treesit-fold-summary-csharp)
+    (csharp-ts-mode         . treesit-fold-summary-csharp)
     (css-mode               . treesit-fold-summary-javadoc)
+    (css-ts-mode            . treesit-fold-summary-javadoc)
     (dart-mode              . treesit-fold-summary-javadoc)
+    (dart-ts-mode           . treesit-fold-summary-javadoc)
     (editorconfig-conf-mode . treesit-fold-summary-ruby-doc)
     (emacs-lisp-mode        . treesit-fold-summary-elisp)
     (elixir-mode            . treesit-fold-summary-ruby-doc)
     (erlang-mode            . treesit-fold-summary-tex-doc)
     (fish-mode              . treesit-fold-summary-javadoc)
+    (fsharp-mode            . treesit-fold-summary-ocaml)
     (gdscript-mode          . treesit-fold-summary-ruby-doc)
+    (gdscript-ts-mode       . treesit-fold-summary-ruby-doc)
     (glsl-mode              . treesit-fold-summary-c)
     (go-mode                . treesit-fold-summary-go)
+    (go-ts-mode             . treesit-fold-summary-go)
     (graphql-mode           . treesit-fold-summary-ruby-doc)
     (groovy-mode            . treesit-fold-summary-javadoc)
     (jenkinsfile-mode       . treesit-fold-summary-javadoc)
     (haskell-mode           . treesit-fold-summary-lua-doc)
+    (haskell-ts-mode        . treesit-fold-summary-lua-doc)
     (haxe-mode              . treesit-fold-summary-javadoc)
     (heex-mode              . treesit-fold-summary-xml)
     (hlsl-mode              . treesit-fold-summary-c)
     (html-mode              . treesit-fold-summary-xml)
     (jai-mode               . treesit-fold-summary-c)
+    (jai-ts-mode            . treesit-fold-summary-c)
     (janet-mode             . treesit-fold-summary-ruby-doc)
+    (janet-ts-mode          . treesit-fold-summary-ruby-doc)
     (java-mode              . treesit-fold-summary-javadoc)
+    (java-ts-mode           . treesit-fold-summary-javadoc)
     (javascript-mode        . treesit-fold-summary-javadoc)
+    (js-ts-mode             . treesit-fold-summary-javadoc)
     (js-mode                . treesit-fold-summary-javadoc)
     (js2-mode               . treesit-fold-summary-javadoc)
     (js3-mode               . treesit-fold-summary-javadoc)
     (json-mode              . treesit-fold-summary-javadoc)
+    (json-ts-mode           . treesit-fold-summary-javadoc)
     (jsonnet-mode           . treesit-fold-summary-javadoc)
+    (jsonnet-ts-mode        . treesit-fold-summary-javadoc)
     (julia-mode             . treesit-fold-summary-julia-doc)
+    (julia-ts-mode          . treesit-fold-summary-julia-doc)
     (kotlin-mode            . treesit-fold-summary-javadoc)
+    (kotlin-ts-mode         . treesit-fold-summary-javadoc)
     (latex-mode             . treesit-fold-summary-tex-doc)
     (LaTeX-mode             . treesit-fold-summary-tex-doc)
     (lisp-mode              . treesit-fold-summary-elisp)
@@ -242,6 +267,7 @@ type of content by checking the word boundary's existence."
     (llvm-mode              . treesit-fold-summary-elisp)
     (llvm-mir-mode          . treesit-fold-summary-elisp)
     (lua-mode               . treesit-fold-summary-lua-doc)
+    (lua-ts-mode            . treesit-fold-summary-lua-doc)
     (magik-mode             . treesit-fold-summary-ruby-doc)
     (makefile-mode          . treesit-fold-summary-ruby-doc)
     (makefile-automake-mode . treesit-fold-summary-ruby-doc)
@@ -253,8 +279,12 @@ type of content by checking the word boundary's existence."
     (matlab-mode            . treesit-fold-summary-matlab-doc)
     (mermaid-mode           . treesit-fold-summary-mermaid)
     (ninja-mode             . treesit-fold-summary-ruby-doc)
+    (nim-mode               . treesit-fold-summary-ruby-doc)
+    (nim-ts-mode            . treesit-fold-summary-ruby-doc)
     (nix-mode               . treesit-fold-summary-ruby-doc)
+    (nix-ts-mode            . treesit-fold-summary-ruby-doc)
     (noir-mode              . treesit-fold-summary-rust-doc)
+    (noir-ts-mode              . treesit-fold-summary-rust-doc)
     (objc-mode              . treesit-fold-summary-c)
     (org-mode               . treesit-fold-summary-org)
     (perl-mode              . treesit-fold-summary-ruby-doc)
@@ -270,19 +300,31 @@ type of content by checking the word boundary's existence."
     (scala-mode             . treesit-fold-summary-javadoc)
     (scheme-mode            . treesit-fold-summary-elisp)
     (sh-mode                . treesit-fold-summary-javadoc)
+    (sh-ts-mode             . treesit-fold-summary-javadoc)
     (sql-mode               . treesit-fold-summary-c)
+    (sql-ts-mode            . treesit-fold-summary-c)
     (svelte-mode            . treesit-fold-summary-xml)
+    (svelte-ts-mode         . treesit-fold-summary-xml)
     (swift-mode             . treesit-fold-summary-c)
+    (swift-ts-mode          . treesit-fold-summary-c)
     (tablegen-mode          . treesit-fold-summary-javadoc)
     (toml-mode              . treesit-fold-summary-javadoc)
+    (toml-ts-mode           . treesit-fold-summary-javadoc)
     (conf-toml-mode         . treesit-fold-summary-javadoc)
     (typescript-mode        . treesit-fold-summary-javadoc)
+    (typescript-ts-mode     . treesit-fold-summary-javadoc)
     (verilog-mode           . treesit-fold-summary-javadoc)
+    (verilog-ts-mode        . treesit-fold-summary-javadoc)
     (vhdl-mode              . treesit-fold-summary-lua-doc)
+    (vhdl-ts-mode           . treesit-fold-summary-lua-doc)
+    (vimrc-mode             . treesit-fold-summary-vim)
+    (vimscript-ts-mode      . treesit-fold-summary-vim)
     (nxml-mode              . treesit-fold-summary-xml)
     (yaml-mode              . treesit-fold-summary-ruby-doc)
+    (yaml-ts-mode           . treesit-fold-summary-ruby-doc)
     (k8s-mode               . treesit-fold-summary-ruby-doc)
-    (zig-mode               . treesit-fold-summary-go))
+    (zig-mode               . treesit-fold-summary-go)
+    (zig-ts-mode            . treesit-fold-summary-go))
   "Alist mapping `major-mode' to doc parser function."
   :type '(alist :key-type symbol :value-type function)
   :group 'treesit-fold)
